@@ -479,7 +479,8 @@ proc_var <- function(s,drop.first=TRUE,maxlen) {
   }
   ## strip comments & whitespace
   s2 <- gsub("^[ \\\t]*","",gsub("[;]*[ \\\t]*$","",strip_comments(s)))
-  s2 <- s2[nchar(s2)>0] 
+  s2 <- s2[nchar(s2)>0]
+  s2 <- s2[!grepl("+[ \\\t]*!!",s2)] ## strip !! lines
   words <- strsplit(s2," ")
   type <- sapply(words,"[[",1)
   rest <- sapply(words,"[[",2)
@@ -771,7 +772,7 @@ run_admb <- function(fn,verbose=FALSE,mcmc=FALSE,mcmc.opts=mcmc.control(),
   outfn <- paste(fn,"out",sep=".")
 
   if (.Platform$OS.type=="windows") {
-    cmdname <- paste(fn,".exe")
+    cmdname <- paste(fn,".exe",sep="")
     shellcmd <- shell
   } else {
     cmdname <- paste("./",fn,sep="")
